@@ -8,7 +8,7 @@ void setWindowTransparency(void *xid, unsigned char val) {
     [win setOpaque:NO];
 }
 
-NSView *my_getContetView(void *xid) {
+NSView *my_getContentView(void *xid) {
     NSWindow *win = (NSWindow *)xid;
     return [win contentView];
 }
